OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Das Schreiben in das \"config\"-Verzeichnis ist nicht möglich!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Wenn du jedoch möchtest dass die Datei config.php schreibgeschützt bleiben soll, dann setze die Option \"config_is_read_only\" in der Datei auf true.",
    "See %s" : "Siehe %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Die Anwendung %1$s ist nicht vorhanden oder hat eine mit diesem Server nicht kompatible Version. Bitte das Apps-Verzeichnis überprüfen.",
    "Sample configuration detected" : "Beispielkonfiguration gefunden",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Es wurde festgestellt, dass die Beispielkonfiguration kopiert wurde. Dies kann deine Installation zerstören und wird nicht unterstützt. Bitte die Dokumentation lesen, bevor Änderungen an der config.php vorgenommen werden.",
    "The page could not be found on the server." : "Die Seite konnte auf dem Server nicht gefunden werden.",
    "%s email verification" : "%s E-Mail-Überprüfung",
    "Email verification" : "E-Mail-Überprüfung",
    "Click the following button to confirm your email." : "Die folgende Schaltfläche anklicken, um die E-Mail-Adresse zu bestätigen.",
    "Click the following link to confirm your email." : "Auf den nachfolgenden Link klicken, um die E-Mail-Adresse zu bestätigen",
    "Confirm your email" : "Bestätige deine E-Mail-Adresse",
    "Other activities" : "Andere Aktivitäten",
    "%1$s and %2$s" : "%1$s und %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s und %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s und %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s und %5$s",
    "Education bundle" : "Bildungspaket",
    "Enterprise bundle" : "Firmen-Paket",
    "Groupware bundle" : "Groupware-Paket",
    "Hub bundle" : "Hub-Paket",
    "Public sector bundle" : "Paket für den öffentlichen Sektor",
    "Social sharing bundle" : "Paket für das Teilen in sozialen Medien",
    "PHP %s or higher is required." : "PHP %s oder höher wird benötigt.",
    "PHP with a version lower than %s is required." : "PHP wird in einer früheren Version als %s benötigt.",
    "%sbit or higher PHP required." : "%sbit oder höheres PHP wird benötigt.",
    "The following architectures are supported: %s" : "Die folgenden Architekturen werden unterstützt: %s",
    "The following databases are supported: %s" : "Die folgenden Datenbanken werden unterstützt: %s",
    "The command line tool %s could not be found" : "Das Kommandozeilenwerkzeug %s konnte nicht gefunden werden",
    "The library %s is not available." : "Die Bibliothek %s ist nicht verfügbar.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Die Bibliothek %1$s wird in einer neueren Version als %2$s benötigt - verfügbare Version ist %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Die Bibliothek %1$s wird in einer früheren Version als %2$s benötigt - verfügbare Version ist %3$s.",
    "The following platforms are supported: %s" : "Die folgenden Plattformen werden unterstützt: %s",
    "Server version %s or higher is required." : "Server Version %s oder höher wird benötigt.",
    "Server version %s or lower is required." : "Server Version %s oder niedriger wird benötigt.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Unteradministrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
    "Your current IP address doesn't allow you to perform admin actions" : "Unter deiner aktuellen IP-Adresse sind keine Administrationsaktionen erlaubt",
    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Unter-)Administrator sein",
    "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrator sein",
    "Wiping of device %s has started" : "Löschen von Gerät %s wurde gestartet",
    "Wiping of device »%s« has started" : "Löschen von Gerät »%s« wurde gestartet",
    "»%s« started remote wipe" : "»%s« hat das Löschen aus der Ferne gestartet",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Gerät oder Anwendung »%s« hat den Vorgang des Löschens aus der Ferne gestartet. Du bekommst eine weitere E-Mail sobald der Vorgang beendet wurde",
    "Wiping of device %s has finished" : "Löschen von Gerät %s wurde beendet",
    "Wiping of device »%s« has finished" : "Löschen von Gerät »%s« wurde beendet",
    "»%s« finished remote wipe" : "»%s« hat das Löschen aus der Ferne beendet",
    "Device or application »%s« has finished the remote wipe process." : "Gerät oder Anwendung »%s« hat den Vorgang des Löschens aus der Ferne beendet.",
    "Remote wipe started" : "Fernlöschung gestartet",
    "A remote wipe was started on device %s" : "Eine Fernlöschung wurde am Gerät %s gestartet",
    "Remote wipe finished" : "Fernlöschung fertig",
    "The remote wipe on %s has finished" : "Die Fernlöschung auf %s ist fertig",
    "Authentication" : "Authentifizierung",
    "Unknown filetype" : "Unbekannter Dateityp",
    "Invalid image" : "Ungültiges Bild",
    "Avatar image is not square" : "Benutzerbild ist nicht quadratisch",
    "Files" : "Dateien",
    "View profile" : "Profil ansehen",
    "same time" : "gleiche Zeit",
    "_%nh_::_%nh_" : ["%nStunde","%nStunden"],
    "_%nm_::_%nm_" : ["%nm","%nm"],
    "%s ahead" : "%s voraus",
    "%s behind" : "%s zurück",
    "Local time: %s" : "Ortszeit: %s",
    "today" : "Heute",
    "tomorrow" : "Morgen",
    "yesterday" : "Gestern",
    "_in %n day_::_in %n days_" : ["in %n Tag","in %n Tagen"],
    "_%n day ago_::_%n days ago_" : ["Vor %n Tag","Vor %n Tagen"],
    "next month" : "Nächsten Monat",
    "last month" : "Letzten Monat",
    "_in %n month_::_in %n months_" : ["in %n Monat","in %n Monaten"],
    "_%n month ago_::_%n months ago_" : ["Vor %n Monat","Vor %n Monaten"],
    "next year" : "nächstes Jahr",
    "last year" : "Letztes Jahr",
    "_in %n year_::_in %n years_" : ["in %n Jahr","in %n Jahren"],
    "_%n year ago_::_%n years ago_" : ["Vor %n Jahr","Vor %n Jahren"],
    "_in %n hour_::_in %n hours_" : ["in %n Stunde","in %n Stunden"],
    "_%n hour ago_::_%n hours ago_" : ["Vor %n Stunde","Vor %n Stunden"],
    "_in %n minute_::_in %n minutes_" : ["in %n Minute","in %n Minuten"],
    "_%n minute ago_::_%n minutes ago_" : ["Vor %n Minute","Vor %n Minuten"],
    "in a few seconds" : "in wenigen Sekunden",
    "seconds ago" : "Gerade eben",
    "Empty file" : "Leere Datei",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Das Modul mit der ID: %s existiert nicht. Bitte die App in den App-Einstellungen aktivieren oder die Administration kontaktieren.",
    "No file conversion providers available" : "Keine Dateikonvertierungsanbieter verfügbar",
    "File is too large to convert" : "Die Datei ist zu groß zum Konvertieren",
    "Destination does not match conversion extension" : "Das Ziel stimmt nicht mit der Konvertierungs-Erweiterung überein",
    "Could not convert file" : "Datei konnte nicht konvertiert werden",
    "Destination does not exist" : "Ziel existiert nicht",
    "Destination is not creatable" : "Ziel kann nicht erstellt werden",
    "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" ist ein unzulässiger Datei- oder Ordnername.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" ist ein unzulässiges Präfix für Datei- oder Ordnernamen.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ist in einem Datei- oder Ordnernamen unzulässig.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" ist ein unzulässiger Dateityp.",
    "Filenames must not end with \"%1$s\"." : "Dateinamen dürfen nicht mit \"%1$s\" enden.",
    "Invalid parent path" : "Ungültiger übergeordneter Pfad",
    "File already exists" : "Datei bereits vorhanden",
    "Invalid path" : "Ungültiger Pfad",
    "Failed to create file from template" : "Fehler beim Erstellen der Datei aus Vorlage",
    "Templates" : "Vorlagen",
    "Storage %s cannot be moved" : "Speicherplatz %s kann nicht verschoben werden",
    "Moving a share (%s) into a shared folder is not allowed" : "Verschieben einer Freigabe (%s) in einen freigegebenen Ordner ist unzulässig",
    "Moving a storage (%s) into a shared folder is not allowed" : "Verschieben eines Speicherplatzes (%s) in einen freigegebenen Ordner ist unzulässig",
    "Moving a share (%s) into another share (%s) is not allowed" : "Verschieben einer Freigabe (%s) in eine andere Freigabe (%s) ist unzulässig.",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Verschieben einer Freigabe (%s) in einen anderen Speicherplatz (%s) ist nicht erlaubt",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Verschieben eines Speicherplatzes (%s) in eine Freigabe (%s) ist nicht erlaubt",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Verschieben eines Speicherplatzes (%s) in einen anderen Speicherplatz (%s) ist nicht erlaubt",
    "Path contains invalid segments" : "Pfad enthält ungültige Segmente",
    "Filename is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
    "Filename contains at least one invalid character" : "Der Dateiname enthält mindestens ein unzulässiges Zeichen.",
    "Filename is too long" : "Dateiname ist zu lang",
    "Empty filename is not allowed" : "Ein leerer Dateiname ist nicht erlaubt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Die Anwendung \"%s\" kann nicht installiert werden, weil die Anwendungsinfodatei nicht gelesen werden kann.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Die App \"%s\" kann nicht installiert werden, da sie mit dieser Serverversion nicht kompatibel ist.",
    "__language_name__" : "Deutsch (Persönlich: Du)",
    "This is an automatically sent email, please do not reply." : "Dies ist eine automatisch gesendete E-Mail. Bitte antworte nicht auf diese E-Mail.",
    "Help & privacy" : "Hilfe & Datenschutz",
    "Appearance and accessibility" : "Erscheinungsbild und Barrierefreiheit",
    "Apps" : "Apps",
    "Personal settings" : "Persönliche Einstellungen",
    "Administration settings" : "Verwaltungseinstellungen",
    "Settings" : "Einstellungen",
    "Log out" : "Abmelden",
    "Accounts" : "Konten",
    "Email" : "E-Mail",
    "Mail %s" : "E-Mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Zeige %s auf dem Fediverse",
    "Phone" : "Telefon",
    "Call %s" : "%s anrufen",
    "Twitter" : "X",
    "View %s on Twitter" : "%s auf X anzeigen",
    "Website" : "Webseite",
    "Visit %s" : "%s besuchen",
    "Address" : "Adresse",
    "Profile picture" : "Profilbild",
    "About" : "Über",
    "Display name" : "Anzeigename",
    "Headline" : "Überschrift",
    "Organisation" : "Organisation",
    "Role" : "Funktion",
    "Pronouns" : "Pronomen",
    "Unknown account" : "Unbekanntes Konto",
    "Additional settings" : "Zusätzliche Einstellungen",
    "Enter the database Login and name for %s" : "Den Datenbankanmeldenamen und den Namen für %s eingeben",
    "Enter the database Login for %s" : "Anmeldenamen für die Datenbank für %s eingeben",
    "Enter the database name for %s" : "Den Datenbanknamen eingeben für %s",
    "You cannot use dots in the database name %s" : "Du kannst keine Punkte im Datenbanknamen %s verwenden.",
    "MySQL Login and/or password not valid" : "MySQL Anmeldename und/oder Passwort ungültig",
    "You need to enter details of an existing account." : "Du musst Details von einem existierenden Benutzer einfügen.",
    "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
    "Oracle Login and/or password not valid" : "Oracle-Anmeldename und/oder -Passwort ungültig",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL-Anmeldename und/oder Passwort ungültig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X wird nicht unterstützt und %s wird unter dieser Plattform nicht richtig funktionieren. Verwendung auf eigene Gefahr!",
    "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte die open_basedir-Einstellung in der php.ini entfernen oder zu 64-Bit-PHP wechseln.",
    "Set an admin Login." : "Anmeldename für Andministration setzen.",
    "Set an admin password." : "Ein Administrationspasswort setzen.",
    "Cannot create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Freigabe-Backend %s muss in der OCP\\Share_Backend - Schnittstelle implementiert werden",
    "Sharing backend %s not found" : "Freigabe-Backend %s nicht gefunden",
    "Sharing backend for %s not found" : "Freigabe-Backend für %s nicht gefunden",
    "%1$s shared %2$s with you" : "%1$s hat %2$s mit dir geteilt",
    "Open %s" : "%s öffnen",
    "%1$s via %2$s" : "%1$s über %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s hat %2$s mit dir geteilt und möchte hinzufügen:",
    "%1$s shared %2$s with you and wants to add" : "%1$s hat %2$s mit dir geteilt und möchte hinzufügen",
    "%s added a note to a file shared with you" : "%s hat eine Notiz zu einer Datei, die mit dir geteilt wurde, hinzugefügt",
    "Passwords are enforced for link and mail shares" : "Für Link- und E-Mail-Freigaben werden Passwörter erzwungen",
    "Share recipient is not a valid user" : "Freigabeempfänger ist kein gültiger Benutzer",
    "Share recipient is not a valid group" : "Freigabeempfänger ist keine gültige Gruppe",
    "Share recipient should be empty" : "Freigabeempfänger sollte leer sein",
    "Share recipient should not be empty" : "Freigabeempfänger sollte nicht leer sein",
    "Share recipient is not a valid circle" : "Freigabeempfänger ist kein gültiger Kreis",
    "Unknown share type" : "Unbekannter Freigabetyp",
    "Share initiator must be set" : "Freigabeinitiator muss festgelegt sein",
    "Cannot share with yourself" : "Es kann nicht mit sich selbst geteilt werden",
    "Shared path must be set" : "Der freigegebene Pfad muss festgelegt werden",
    "Shared path must be either a file or a folder" : "Der freigegebene Pfad muss entweder eine Datei oder ein Ordner sein",
    "You cannot share your root folder" : "Du kannst deinen Stammordner nicht freigeben",
    "You are not allowed to share %s" : "Du bist nicht berechtigt, %s zu teilen.",
    "Valid permissions are required for sharing" : "Zum Teilen sind gültige Berechtigungen erforderlich",
    "File shares cannot have create or delete permissions" : "Dateifreigaben können keine Berechtigungen zum Erstellen oder Löschen haben",
    "Cannot increase permissions of %s" : "Kann die Berechtigungen von %s nicht erhöhen",
    "Shares need at least read permissions" : "Freigaben benötigen mindestens Leseberechtigungen",
    "Files cannot be shared with delete permissions" : "Dateien mit Lösch-Berechtigungen können nicht geteilt werden",
    "Files cannot be shared with create permissions" : "Dateien mit Erstell-Berechtigungen können nicht geteilt werden",
    "Expiration date is in the past" : "Das Ablaufdatum liegt in der Vergangenheit.",
    "Expiration date is enforced" : "Ablaufdatum wird erzwungen",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Das Ablaufdatum kann nicht mehr als %n Tag in der Zukunft liegen","Das Ablaufdatum kann nicht mehr als %n Tage in der Zukunft liegen"],
    "Sharing is only allowed with group members" : "Teilen ist nur mit Gruppenmitgliedern erlaubt",
    "Sharing %s failed, because this item is already shared with the account %s" : "Freigeben von %s ist fehlgeschlagen, da dieses Element schon mit dem Konto %s geteilt wurde",
    "Group sharing is now allowed" : "Gruppenfreigabe ist jetzt erlaubt",
    "Sharing is only allowed within your own groups" : "Das Teilen ist nur innerhalb deiner eigenen Gruppen erlaubt",
    "Path is already shared with this group" : "Der Pfad ist bereits mit dieser Gruppe geteilt",
    "Link sharing is not allowed" : "Freigabe via Link ist nicht erlaubt",
    "Public upload is not allowed" : "Öffentliches Hochladen ist nicht erlaubt",
    "You cannot share a folder that contains other shares" : "Ein Ordner, der andere Freigaben enthält, kann nicht geteilt werden",
    "Sharing is disabled" : "Teilen ist deaktiviert",
    "Sharing is disabled for you" : "Teilen ist für dich deaktiviert",
    "Cannot share with the share owner" : "Teilen mit dem Freigabeeigentümer nicht möglich",
    "Share does not have a full ID" : "Die Freigabe hat keine vollständige ID",
    "Cannot change share type" : "Der Freigabetyp kann nicht geändert werden",
    "Can only update recipient on user shares" : "Empfänger können nur bei Benutzerfreigaben aktualisiert werden",
    "Cannot enable sending the password by Talk with an empty password" : "Das Senden des Passworts über Talk kann mit einem leeren Passwort nicht aktiviert werden",
    "Cannot enable sending the password by Talk without setting a new password" : "Das Senden des Passworts über Talk kann nicht aktiviert werden, ohne ein neues Passwort festzulegen",
    "Cannot disable sending the password by Talk without setting a new password" : "Das Senden des Passworts durch Talk kann nicht deaktiviert werden, ohne ein neues Passwort festzulegen",
    "Share provider does not support accepting" : "Der Teilen-Anbieter unterstützt das Akzeptieren nicht",
    "Cannot change target of link share" : "Das Ziel der Linkfreigabe kann nicht geändert werden",
    "Invalid share recipient" : "Ungültiger Freigabeempfänger",
    "Group \"%s\" does not exist" : "Gruppe \"%s\" existiert nicht",
    "The requested share does not exist anymore" : "Die angeforderte Freigabe existiert nicht mehr",
    "The requested share comes from a disabled user" : "Die angeforderte Freigabe stammt von einem deaktivierten Benutzer",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Der Benutzer wurde nicht erstellt, da das Benutzerlimit erreicht wurde. Überprüfe deine Benachrichtigungen, um mehr zu erfahren.",
    "Could not find category \"%s\"" : "Die Kategorie \"%s\" konnte nicht gefunden werden",
    "Input text" : "Texteingabe",
    "The input text" : "Der Eingabetext",
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sun." : "Son.",
    "Mon." : "Mon.",
    "Tue." : "Die.",
    "Wed." : "Mit.",
    "Thu." : "Don.",
    "Fri." : "Fre.",
    "Sat." : "Sam.",
    "Su" : "So",
    "Mo" : "Mo",
    "Tu" : "Di",
    "We" : "Mi",
    "Th" : "Do",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mär.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "A valid password must be provided" : "Es muss ein gültiges Passwort eingegeben werden",
    "The Login is already being used" : "Dieser Anmeldename wird bereits verwendet",
    "Could not create account" : "Konto konnte nicht erstellt werden",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Nur die folgenden Zeichen sind in einem Anmeldenamen erlaubt: \"a-z\", \"A-Z\", \"0-9\", Leerzeichen und \"_.@-'\"",
    "A valid Login must be provided" : "Ein gültiger Anmeldename muss eingegeben werden.",
    "Login contains whitespace at the beginning or at the end" : "Anmeldename enthält Leerzeichen am Anfang oder am Ende",
    "Login must not consist of dots only" : "Der Anmeldename darf nicht nur aus Punkten bestehen",
    "Login is invalid because files already exist for this user" : "Der Anmeldename ist ungültig, da bereits Dateien von diesem Konto existieren",
    "Account disabled" : "Konto deaktiviert",
    "Login canceled by app" : "Anmeldung durch die App abgebrochen",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Die App \"%1$s\" kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %2$s",
    "a safe home for all your data" : "ein sicherer Ort für all deine Daten",
    "Application is not enabled" : "Die Anwendung ist nicht aktiviert",
    "Authentication error" : "Authentifizierungsfehler",
    "Token expired. Please reload page." : "Token abgelaufen. Bitte lade die Seite neu.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Keine Datenbanktreiber (SQLite, MySQL oder PostgreSQL) installiert.",
    "Cannot write into \"config\" directory." : "Schreiben in das \"config\"-Verzeichnis ist nicht möglich.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Oder wenn du lieber möchtest, dass die Datei config.php schreibgeschützt bleiben soll, dann setze die Option \"config_is_read_only\" in der Datei auf true. Siehe %s",
    "Cannot write into \"apps\" directory." : "Schreiben in das \"apps\"-Verzeichnis ist nicht möglich.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird, oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
    "Cannot create \"data\" directory." : "Kann das \"data\"-Verzeichnis nicht erstellen.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Berechtigungen können zumeist korrigiert werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
    "Your data directory is not writable." : "Das Datenverzeichnis ist schreibgeschützt.",
    "Setting locale to %s failed." : "Das Setzen der Spracheeinstellung auf %s ist fehlgeschlagen.",
    "Please install one of these locales on your system and restart your web server." : "Bitte eine dieser Sprachen auf dem System installieren und den Webserver neu starten.",
    "PHP module %s not installed." : "PHP-Modul %s nicht installiert.",
    "Please ask your server administrator to install the module." : "Bitte für die Installation des Moduls die Serveradministration kontaktieren.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung \"%s\" ist nicht auf \"%s\" gesetzt.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Eine Änderung dieser Einstellung in der php.ini kann diese Nextcloud wieder lauffähig machen.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Zum Beheben dieses Problems bitte <code>mbstring.func_overload</code> in der php.ini auf <code>0</code> setzen.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
    "Please ask your server administrator to restart the web server." : "Bitte die Serveradministration konatktieren und um Neustart des Webservers bitten.",
    "The required %s config variable is not configured in the config.php file." : "Die erforderliche %s Konfigurationsvariable ist in der config.php nicht konfiguriert.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Die Serveradministration bitten, die Nextcloud-Konfiguration zu überprüfen.",
    "Your data directory is readable by other people." : "Dein Datenverzeichnis kann von anderen Benutzern gelesen werden",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Bitte die Berechtigungen auf 0770 ändern, so dass das Verzeichnis nicht von Anderen angezeigt werden kann.",
    "Your data directory must be an absolute path." : "Das Datenverzeichnis muss einen eindeutigen Pfad haben",
    "Check the value of \"datadirectory\" in your configuration." : "Bitte die Angabe unter \"datadirectory\" in der Konfiguration überprüfen.",
    "Your data directory is invalid." : "Das Datenverzeichnis ist ungültig",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Bitte sicherstellen, dass eine Datei \"%1$s\" im Wurzelverzeichnis des Datenverzeichnisses existiert. Sie sollte folgenden Inhalt haben: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Aktion \"%s\" wird nicht unterstützt oder ist nicht implementiert.",
    "Authentication failed, wrong token or provider ID given" : "Authentifizierung ist fehlgeschlagen. Falsches Token oder falsche Provider-ID wurde übertragen.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Es fehlen Parameter, um die Anfrage zu bearbeiten. Fehlende Parameter: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" wird bereits von Cloud-Federation-Provider \"%2$s\" verwendet",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud-Federation-Provider mit ID: \"%s\" ist nicht vorhanden.",
    "Could not obtain lock type %d on \"%s\"." : "Sperrtyp %d auf \"%s\" konnte nicht ermittelt werden.",
    "Storage unauthorized. %s" : "Speicher nicht autorisiert. %s",
    "Storage incomplete configuration. %s" : "Speicher-Konfiguration unvollständig. %s",
    "Storage connection error. %s" : "Verbindungsfehler zum Speicherplatz. %s",
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Damit diese Prüfung ausgeführt werden kann, muß sichergestellt sein, dass der Webserver eine Verbindung zu sich selbst herstellen kann. Daher muss er in der Lage sein, mindestens eine seiner `trusted_domains` oder `overwrite.cli.url` aufzulösen und eine Verbindung zu ihnen herzustellen. Dieser Fehler kann das Ergebnis einer serverseitigen DNS-Nichtübereinstimmung oder einer ausgehenden Firewall-Regel sein.",
    "Transcribe audio" : "Audio transkribieren",
    "Transcribe the things said in an audio" : "Inhalt der Audiodatei transkribieren",
    "Audio input" : "Audioeingang",
    "The audio to transcribe" : "Die Audio-Datei zum Transkribieren",
    "Transcription" : "Transkription",
    "The transcribed text" : "Der transkribierte Text",
    "Chat with an agent" : "Mit einem Agenten chatten",
    "Chat message" : "Chatnachricht",
    "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
    "Confirmation" : "Bestätigung",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Ob zuvor angeforderte Aktionen bestätigt werden sollen: 0 für Verweigerung und 1 für Bestätigung.",
    "Conversation token" : "Unterhaltungstoken",
    "A token representing the conversation." : "Ein Token, das die Unterhaltung repräsentiert.",
    "Generated response" : "Erzeugte Antwort",
    "The response from the chat model." : "Die Antwort des Chat-Modells.",
    "The new conversation token" : "Das neue Unterhaltungstoken",
    "Send this along with the next interaction." : "Dies zusammen mit der nächsten Interaktion senden.",
    "Requested actions by the agent" : "Vom Agenten angeforderte Aktionen",
    "Actions that the agent would like to carry out in JSON format." : "Aktionen, die der Agent durchführen möchte, im JSON-Format.",
    "Context write" : "Kontext schreiben",
    "Writes text in a given style based on the provided source material." : "Schreibt Text in einem vorgegebenen Stil auf Basis des bereitgestellten Quellmaterials.",
    "Writing style" : "Schreibstil",
    "Demonstrate a writing style that you would like to immitate" : "Zeige einen Schreibstil, den du gerne nachahmen würden",
    "Source material" : "Quellmaterial",
    "The content that would like to be rewritten in the new writing style" : "Der Inhalt, der in den neuen Schreibstil umgeschrieben werden soll",
    "Generated text" : "Erstellter Text",
    "The generated text with content from the source material in the given style" : "Der erstellte Text mit Inhalten aus dem Quellmaterial im angegebenen Stil",
    "Emoji generator" : "Emoji-Generator",
    "Takes text and generates a representative emoji for it." : "Erstellt aus eingegebenem Text ein repräsentatives Emoji.",
    "The text to generate an emoji for" : "Der Text aus dem ein Emoji erstellt werden soll",
    "Generated emoji" : "Erstelltes Emoji",
    "The generated emoji based on the input text" : "Das aus dem eingegebenen Text erstelltes Emoji",
    "Generate image" : "Bild erstellen",
    "Generate an image from a text prompt" : "Bild aus einer Texteingabe erstellen",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Das Bild, das erstellt werden soll, beschreiben",
    "Number of images" : "Anzahl der Bilder",
    "How many images to generate" : "Wie viele Bilder erstellt werden sollen",
    "Output images" : "Ausgegebene Bilder",
    "The generated images" : "Die erstellten Bilder",
    "Free text to text prompt" : "Freie Text-zu-Text-Eingabeaufforderung",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Führt eine beliebige Eingabeaufforderung mit einem Sprachmodell aus, das eine Antwort zurückgibt",
    "Describe a task that you want the assistant to do or ask a question" : "Eine Aufgabe beschreiben, die der Assistent erledigen soll, oder eine Frage stellen",
    "Generated reply" : "Erstellte Antwort",
    "The generated text from the assistant" : "Der vom Assistenten erstellte Text",
    "Change Tone" : "Ton ändern",
    "Change the tone of a piece of text." : "Den Ton eines Textes ändern.",
    "Write a text that you want the assistant to rewrite in another tone." : "Schreibe einen Text, den der Assistent in einen anderen Ton umschreiben soll.",
    "Desired tone" : "Gewünschter Ton",
    "In which tone should your text be rewritten?" : "In welchem Ton soll Dein Text umgeschrieben werden?",
    "The rewritten text in the desired tone, written by the assistant:" : "Der umgeschriebene Text im gewünschten Ton, erstellt vom Assistenten:",
    "Chat" : "Chat",
    "Chat with the assistant" : "Mit dem Assistenten chatten",
    "System prompt" : "Systemaufforderung",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Regeln und Annahmen definieren, die der Assistent während des Gesprächs befolgen soll.",
    "Chat history" : "Chatverlauf",
    "The history of chat messages before the current message, starting with a message by the user" : "Chatverlauf vor der aktuellen Nachricht, beginnend mit einer Nachricht des Benutzers",
    "Response message" : "Antwortnachricht",
    "The generated response as part of the conversation" : "Die erstellte Antwort als Teil der Unterhaltung",
    "Chat with tools" : "Chat mit Tools",
    "Chat with the language model with tool calling support." : "Chatten mit dem Sprachmodell mit Unterstützung für Tool-Aufrufe.",
    "Tool message" : "Tool-Nachricht",
    "The result of tool calls in the last interaction" : "Das Ergebnis der Tool-Aufrufe in der letzten Interaktion",
    "Available tools" : "Verfügbare Tools",
    "The available tools in JSON format" : "Die verfügbaren Tools im JSON-Format",
    "The response from the chat model" : "Die Antwort vom Chat-Modell",
    "Tool calls" : "Tool-Anrufe",
    "Tools call instructions from the model in JSON format" : "Tool's Anruf-Anweisungen aus dem Modell im JSON-Format",
    "Formalize text" : "Förmlicher Text",
    "Takes a text and makes it sound more formal" : "Verleiht einem Text mehr Förmlichkeit",
    "Write a text that you want the assistant to formalize" : "Text schreiben, den der Assistent förmlich umschreiben soll",
    "Formalized text" : "Förmlicher Text",
    "The formalized text" : "Der förmliche Text",
    "Generate a headline" : "Eine Überschrift erstellen",
    "Generates a possible headline for a text." : "Erzeugt eine mögliche Überschrift für einen Text.",
    "Original text" : "Originaltext",
    "The original text to generate a headline for" : "Der Originaltext, für den eine Überschrift erstellt werden soll",
    "The generated headline" : "Die erstellte Überschrift",
    "Proofread" : "Korrekturlesen",
    "Proofreads a text and lists corrections" : "Liest einen Text Korrektur und listet Korrekturen auf",
    "Text" : "Text",
    "The text to proofread" : "Der zu korrigierende Text",
    "Corrections" : "Korrekturen",
    "The corrections that should be made in your text" : "Die Korrekturen, die in deinem Text vorgenommen werden sollten",
    "Reformulate text" : "Text umformulieren",
    "Takes a text and reformulates it" : "Formuliert einen Text um",
    "Write a text that you want the assistant to reformulate" : "Text schreiben, den der Assistent umformulieren soll",
    "Reformulated text" : "Umformulierter Text",
    "The reformulated text, written by the assistant" : "Der vom Assistenten erstellte umfomulierte Text",
    "Simplify text" : "Text vereinfachen",
    "Takes a text and simplifies it" : "Vereinfacht einen Text",
    "Write a text that you want the assistant to simplify" : "Text schreiben, den der Assistent vereinfachen soll",
    "Simplified text" : "Vereinfachter Text",
    "The simplified text" : "Der vereinfachte Text",
    "Summarize" : "Zusammenfassen",
    "Summarizes a text" : "Fasst einen Text zusammen",
    "The original text to summarize" : "Der Originaltext zum Zusammenfassen",
    "Summary" : "Zusammenfassung",
    "The generated summary" : "Die erstellte Zusammenfassung",
    "Extract topics" : "Themen extrahieren",
    "Extracts topics from a text and outputs them separated by commas" : "Extrahiert Themen aus einem Text und gibt diese durch Kommas getrennt aus",
    "The original text to extract topics from" : "Der Originaltext, aus dem Themen extrahiert werden sollen",
    "Topics" : "Themen",
    "The list of extracted topics" : "Liste der extrahierten Themen",
    "Translate" : "Übersetzen",
    "Translate text from one language to another" : "Text von einer Sprache in eine andere übersetzen",
    "Origin text" : "Ausgangstext",
    "The text to translate" : "Der zu übersetzende Text",
    "Origin language" : "Ausgangssprache",
    "The language of the origin text" : "Die Sprache des Ausgangstextes",
    "Target language" : "Zielsprache",
    "The desired language to translate the origin text in" : "Die gewünschte Sprache, in die der Ausgangstext übersetzt werden soll",
    "Result" : "Ergebnis",
    "The translated text" : "Der übersetzte Text",
    "Free prompt" : "Freie Eingabeaufforderung",
    "Runs an arbitrary prompt through the language model." : "Führt eine beliebige Eingabeaufforderung über das Sprachmodell aus.",
    "Generate headline" : "Überschrift erzeugen",
    "Summarizes text by reducing its length without losing key information." : "Fasst Text zusammen, indem die Länge reduziert wird, ohne dass wichtige Informationen verloren gehen.",
    "Extracts topics from a text and outputs them separated by commas." : "Extrahiert Themen aus einem Text und gibt sie durch Kommas getrennt aus.",
    "Education Edition" : "Bildungsausgabe",
    "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
    "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
    "File name is too long" : "Dateiname ist zu lang",
    "Users" : "Benutzer",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s hat »%2$s« mit dir geteilt und möchte folgendes hinzufügen:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$shat »%2$s« mit dir geteilt und möchte folgendes hinzufügen",
    "»%s« added a note to a file shared with you" : "»%s« hat eine Bemerkung zu einer mit dir geteilten Datei hinzugefügt",
    "Open »%s«" : "»%s« öffnen",
    "%1$s shared »%2$s« with you" : "%1$s hat »%2$s« mit dir geteilt",
    "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit dir geteilt.",
    "Click the button below to open it." : "Klicke zum Öffnen auf die untere Schaltfläche.",
    "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte versuche es später noch einmal",
    "Cannot download file" : "Datei kann nicht heruntergeladen werden.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Stelle sicher, dass eine Datei \".ocdata\" im Wurzelverzeichnis des data-Verzeichnisses existiert."
},
"nplurals=2; plural=(n != 1);");
